@@ -10,9 +10,11 @@ import logging
 from flask import jsonify, make_response, Response
 
 
+from flask import request
+
 from JuMonC.handlers.base import RESTAPI
 from JuMonC._version import __version__
-from JuMonC.tasks import taskID, taskSwitcher
+from JuMonC.tasks import mpiroot, mpibase
 from JuMonC.authentication import scopes
 from JuMonC.authentication.check import check_auth
 
@@ -25,13 +27,20 @@ def ping() -> str:
     return "PONG.\n"
 
 
+
 @RESTAPI.route("/stop")
 @check_auth(scopes["full"])
 def stopJuMonC() -> Response:
+    logging.info("Stopping JuMonC")
     
+    logging.debug("stopping flask")
+    func = request.environ.get('werkzeug.server.shutdown')
+    if func is not None:
+        func()
     
-    taskSwitcher.taskSwitcher().addTask([taskID.finalize])
-    
+    logging.debug("Finalizing MPI")
+    mpiroot.sendCommand([mpibase.stop_handlers_id, -1])
+
     return make_response(jsonify("Stopping server and shutting down JuMonC\n"), 200)
 
 
@@ -39,3 +48,9 @@ def stopJuMonC() -> Response:
 def version() -> Response:
     response_body = {"JuMonC_version": __version__}
     return make_response(jsonify(response_body), 200)
+
+
+@RESTAPI.route("/all_links", methods=["GET"])
+@check_auth(scopes["full"])
+def allLinks() -> Response:
+    return make_response(jsonify(RESTAPI.url_map), 200)
\ No newline at end of file
