@@ -5,7 +5,7 @@ from flask import abort, jsonify, make_response, Response, request
 from typing import Dict, List, Union
 
 
-from JuMonC.handlers.base import api_version_path, check_version, RESTAPI
+from JuMonC.handlers.base import api_version_path, check_version, RESTAPI, generate_cache_id, get_prefer_id_description
 from JuMonC.models import pluginInformation
 from JuMonC.tasks import CPU
 from JuMonC.authentication import scopes
@@ -44,8 +44,9 @@ def returnCPUConfigLinks(version: int) -> Response:
     return make_response(jsonify(sorted(config_links, key=lambda dic: dic['link'])), 200)
 
 def registerRestApiPaths(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
-    links.append(registerStatusLinks(version))
-    links.append(registerConfigLinks(version))
+    if pluginInformation.pluginIsWorking("JuMonC_CPUPlugin") is True:
+        links.append(registerStatusLinks(version))
+        links.append(registerConfigLinks(version))
     return {
         "link": "/v" + str(version) + cpu_path,
         "isOptional": False,
@@ -58,34 +59,41 @@ def registerRestApiPaths(version: int) -> Dict[str, Union[bool, str, List[Dict[s
 
 def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
     
-    types : List[str] = ["load"]
-    descriptions : List[str] = ["Get the system load, duration can be 1,5 or 15 min"]
-    if pluginInformation.cpu_is_working:
+    types: List[str] = ["load",
+                        "percent",
+                        "frequency"]
+    descriptions: List[str] = ["Get the system load, duration can be 1,5 or 15 min",
+                               "Get the CPU utilization in percent",
+                               "Get the CPU frequency in MHz"]
+    if pluginInformation.pluginIsWorking("JuMonC_CPUPlugin") is True:
+        parameters = [  {"name": "node",
+                        "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
+                        {"name": "token",
+                        "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}]
+        parameters.append(get_prefer_id_description())
+        
         for i, typeStr in enumerate(types):
             status_links.append({
             "link": "/v" + str(version) + cpu_path + "/status/" + typeStr,
             "isOptional": True,
             "description": descriptions[i],
-            "parameters": [
-                {"name": "node",
-                "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
-                {"name": "token",
-                "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}]
+            "parameters": parameters
             })
         
         @RESTAPI.route(api_version_path + cpu_path + "/status/<string:datatype>", methods=["GET"])
         @check_version
         @check_auth(scopes["compute_data"])
-        def returnCPUStatus(version: int, datatype:str) -> Response:
+        @generate_cache_id
+        def returnCPUStatus(version: int, datatype:str, cache_id: int) -> Response:
             humanReadable = request.args.get('humanReadable', default = settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS, type = settings.helpers.parse_boolean)
             logging.debug("Accessed /v%i/cpu/status/%s", version, datatype)
             
-            cache_id = cache.add_cache_entry("/v" + str(version) + "/cpu/status/" + datatype)
             
             data = CPU.plugin.getStatusData(dataType = datatype,
                                             overrideHumanReadableWithValue = humanReadable)
             if len(data) > 0:
                 for data_element in data:
+                    logging.debug(str(data_element))
                     for result_name, result in data_element.items():
                         cache.addResult(cache_id, result_name, result)
                 cache.commit()
@@ -108,10 +116,10 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
 def registerConfigLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
     types : List[str] = []
     descriptions : List[str] = []
-    if pluginInformation.cpu_is_working:
+    if pluginInformation.pluginIsWorking("JuMonC_CPUPlugin") is True:
         for i, typeStr in enumerate(types):
             config_links.append({
-            "link": "/v" + str(version) + cpu_path + "/status/" + typeStr,
+            "link": "/v" + str(version) + cpu_path + "/config/" + typeStr,
             "isOptional": True,
             "description": descriptions[i],
             "parameters": [
@@ -119,7 +127,7 @@ def registerConfigLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
                 "description": "When this parameter is not present the raw data value(s) will be provided, otherwise the average value per second"},
                 {"name": "humanReadable",
                 "description": "For 'True' convert to better readable numbers, for 'False' return actual number. " + 
-                 "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
+                "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
                 {"name": "node",
                 "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
                 {"name": "token",
