@@ -5,7 +5,7 @@ from flask import abort, jsonify, make_response, Response, request
 from typing import Dict, List, Union
 
 
-from JuMonC.handlers.base import api_version_path, check_version, RESTAPI
+from JuMonC.handlers.base import api_version_path, check_version, RESTAPI, generate_cache_id, get_prefer_id_description
 from JuMonC.authentication import scopes
 from JuMonC.authentication.check import check_auth
 from JuMonC.models import pluginInformation
@@ -58,31 +58,33 @@ def registerRestApiPaths(version: int) -> Dict[str, Union[bool, str, List[Dict[s
 
 
 def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
-    if pluginInformation.nvidia_is_working:
+    if pluginInformation.pluginIsWorking("JuMonC_NvidiaPlugin") is True:
+        parameters = [  {"name": "humanReadable",
+                        "description": "For 'True' convert to better readable numbers, for 'False' return actual number. " + 
+                            "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
+                        {"name": "node",
+                        "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
+                        {"name": "token",
+                        "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}]
+        parameters.append(get_prefer_id_description())
+        
         types = Nvidia.plugin.getStatusList()
         for typeStr in types:
             status_links.append({
             "link": "/v" + str(version) + gpu_path + "/status/" + typeStr,
             "isOptional": True,
             "description": "Nvidia SMI status data, for detailed description see: nvidia-smi --help-query-gpu",
-            "parameters": [
-                {"name": "humanReadable",
-                "description": "For 'True' convert to better readable numbers, for 'False' return actual number. " + 
-                 "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
-                {"name": "node",
-                "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
-                {"name": "token",
-                "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}]
+            "parameters": parameters
             })
         
         @RESTAPI.route(api_version_path + gpu_path + "/status/<string:datatype>", methods=["GET"])
         @check_version
         @check_auth(scopes["compute_data"])
-        def returnGPUStatus(version: int, datatype:str) -> Response:
+        @generate_cache_id
+        def returnGPUStatus(version: int, datatype:str, cache_id:int) -> Response:
             humanReadable = request.args.get('humanReadable', default = settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS, type = settings.helpers.parse_boolean)
             logging.debug("Accessed /v%i/gpu/status/%s with humanReadable=%s", version, datatype, humanReadable)
             
-            cache_id = cache.add_cache_entry("/v" + str(version) + "/gpu/status/" + datatype)
             
             data = Nvidia.plugin.getStatusData(dataType = datatype)
             if len(data) > 0:
@@ -105,7 +107,7 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
 
 
 def registerConfigLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
-    if pluginInformation.nvidia_is_working:
+    if pluginInformation.pluginIsWorking("JuMonC_NvidiaPlugin") is True:
         types = Nvidia.plugin.getStatusList()
         for typeStr in types:
             config_links.append({
