@@ -5,7 +5,7 @@ from flask import abort, jsonify, make_response, Response, request
 from typing import Dict, List, Union
 
 
-from JuMonC.handlers.base import api_version_path, check_version, RESTAPI
+from JuMonC.handlers.base import api_version_path, check_version, RESTAPI, generate_cache_id, get_prefer_id_description
 from JuMonC.authentication import scopes
 from JuMonC.authentication.check import check_auth
 from JuMonC.models import pluginInformation
@@ -60,33 +60,36 @@ def registerRestApiPaths(version: int) -> Dict[str, Union[bool, str, List[Dict[s
 def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
     types : List[str] = ["free", "used"]
     descriptions : List[str] = ["Get the average free memory on your nodes", "Get the average free memeory on your nodes"]
-    if pluginInformation.memory_is_working:
+    if pluginInformation.pluginIsWorking("JuMonC_memoryPlugin") is True:
+        parameters = [  {"name": "duration",
+                        "description": "When this parameter is not present the raw data value(s) will be provided, otherwise the average value per second"},
+                        {"name": "humanReadable",
+                        "description": "For 'True' convert to better readable numbers, for 'False' return actual number. " + 
+                        "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
+                        {"name": "node",
+                        "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
+                        {"name": "token",
+                        "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}]
+                
+        parameters.append(get_prefer_id_description())
+        
         for i, typeStr in enumerate(types):
             status_links.append({
             "link": "/v" + str(version) + main_memory_path + "/status/" + typeStr,
             "isOptional": True,
             "description": descriptions[i],
-            "parameters": [
-                {"name": "duration",
-                "description": "When this parameter is not present the raw data value(s) will be provided, otherwise the average value per second"},
-                {"name": "humanReadable",
-                "description": "For 'True' convert to better readable numbers, for 'False' return actual number. " + 
-                 "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
-                {"name": "node",
-                "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
-                {"name": "token",
-                "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}]
+            "parameters": parameters
             })
         
         @RESTAPI.route(api_version_path + main_memory_path + "/status/<string:datatype>", methods=["GET"])
         @check_version
         @check_auth(scopes["compute_data"])
-        def returnMemoryStatus(version: int, datatype:str) -> Response:
+        @generate_cache_id
+        def returnMemoryStatus(version: int, datatype:str, cache_id:int) -> Response:
             duration = request.args.get('duration', default = -1.0, type = float)
             humanReadable = request.args.get('humanReadable', default = settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS, type = settings.helpers.parse_boolean)
             logging.debug("Accessed /v%i/main_memory/status/%s", version, datatype)
             
-            cache_id = cache.add_cache_entry("/v" + str(version) + "/main_memory/status/" + datatype)
             if duration >0:
                 cache.addParameter(cache_id, "duration", str(duration))
                 cache.commit()
@@ -118,7 +121,7 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
 def registerConfigLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
     types : List[str] = ["total"]
     descriptions : List[str] = ["Get the average total memory on your nodes"]
-    if pluginInformation.memory_is_working:
+    if pluginInformation.pluginIsWorking("JuMonC_memoryPlugin") is True:
         for i, typeStr in enumerate(types):
             config_links.append({
             "link": "/v" + str(version) + main_memory_path + "/config/" + typeStr,
