@@ -1,11 +1,11 @@
 import logging
 
-from flask import abort, jsonify, make_response, Response, request
+from flask import jsonify, make_response, Response, request
 
 from typing import Dict, List, Union
 
 
-from JuMonC.handlers.base import api_version_path, check_version, RESTAPI
+from JuMonC.handlers.base import api_version_path, check_version, RESTAPI, generate_cache_id, get_prefer_id_description
 from JuMonC.models import pluginInformation
 from JuMonC.authentication import scopes
 from JuMonC.authentication.check import check_auth
@@ -48,35 +48,40 @@ def registerRestApiPaths(version: int) -> Dict[str, Union[bool, str, List[Dict[s
     }
 
 def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
-    if pluginInformation.network_is_working:
+    if pluginInformation.pluginIsWorking("JuMonC_LinuxNetworkPlugin") is True:
         types = LinuxNetwork.plugin.getAvaiableDataTypes()
         descriptions = LinuxNetwork.plugin.getAvaiableDataTypesDescriptions()
         types.append("All")
         descriptions.append("get all network status information")
+        
+        parameters = [{ "name": "duration",
+                        "description": "When this parameter is not present the raw data value(s) will be provided, otherwise the average value per second"},
+                        {"name": "interface",
+                        "description": ("When this parameter is not present, information for all network " +
+                                        "interfaces are collected, otherwise only for the specified " + 
+                            "interface. Avaiable interfaces: " + str(LinuxNetwork.plugin.getAvaiableInterfaces()))},
+                        {"name": "humanReadable",
+                        "description": "For 'True' convert to better readable numbers, for 'False' return actual number. " + 
+                            "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
+                        {"name": "node",
+                        "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
+                        {"name": "token",
+                        "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}]
+        parameters.append(get_prefer_id_description())
+            
+        
         for i, typeStr in enumerate(types):
             status_links.append({
             "link": "/v" + str(version) + network_path + "/status/" + typeStr,
             "isOptional": True,
             "description": descriptions[i],
-            "parameters": [
-                {"name": "duration",
-                "description": "When this parameter is not present the raw data value(s) will be provided, otherwise the average value per second"},
-                {"name": "interface",
-                "description": ("When this parameter is not present information for all network interfaces are collected, otherwise only for the specified " + 
-                     "interface. Avaiable interfaces: " + str(LinuxNetwork.plugin.getAvaiableInterfaces()))},
-                {"name": "humanReadable",
-                "description": "For 'True' convert to better readable numbers, for 'False' return actual number. " + 
-                 "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
-                {"name": "node",
-                "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
-                {"name": "token",
-                "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}]
-            })
+            "parameters": parameters})
         
         @RESTAPI.route(api_version_path + network_path + "/status/<string:datatype>", methods=["GET"])
         @check_version
         @check_auth(scopes["compute_data"])
-        def returnLinuxNetworkStatus(version: int, datatype:str) -> Response:
+        @generate_cache_id
+        def returnLinuxNetworkStatus(version: int, datatype:str, cache_id: int) -> Response:
             interface = request.args.get('interface', default = "all", type = str)
             duration = request.args.get('duration', default = -1.0, type = float)
             humanReadable = request.args.get('humanReadable', default = settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS, type = settings.helpers.parse_boolean)
@@ -85,11 +90,11 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
             dataTypes = LinuxNetwork.plugin.getAvaiableDataTypes()
             dataTypes.append("All")
             if datatype in dataTypes:
-                cache_id = cache.add_cache_entry("/v" + str(version) + "/network/status/" + datatype)
+                #cache_id = cache.add_cache_entry("/v" + str(version) + "/network/status/" + datatype)
                 if duration > 0:
                     cache.addParameter(cache_id, "duration", str(duration))
                 cache.addParameter(cache_id, "interface", interface)
-                cache.commit()
+                # cache.commit()
                 
                 data = networkStatusTask(cache_id = cache_id,
                                          duration = duration,
@@ -99,8 +104,7 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
                 if data is None:
                     return make_response(jsonify({"link": "/v" + str(version) + "/cache/id/?id=" + str(cache_id)}), 200)
                 return make_response(jsonify(data, 200))
-            abort(404)
-            return make_response("",404)
+            return make_response("Invalid data type choosen",404)
         
     return {
         "link": "/v" + str(version) + network_path + "/status",
@@ -132,4 +136,4 @@ def networkStatusTask(cache_id: int, duration: float, datatype: str, interface:
                 for result_name, result in part.items():
                     cache.addResult(cache_id, interface_str + "_" + result_part_name + "_" + result_name, result)
     cache.commit()
-    return data
\ No newline at end of file
+    return data
