@@ -8,7 +8,7 @@ from typing import Dict, List, Union
 from JuMonC.handlers.base import api_version_path, check_version, RESTAPI
 from JuMonC.authentication import scopes
 from JuMonC.authentication.check import check_auth
-from JuMonC.handlers import cache, cpu, gpu, io, job, main_memory, network
+from JuMonC.handlers import cache, cpu, gpu, io, job, main_memory, network, planed
 
 
 logger = logging.getLogger(__name__)
@@ -34,6 +34,7 @@ def registerRestApiPaths(version: int) -> Dict[str, Union[bool, str, List[Dict[s
     links_this_version.append(job.registerRestApiPaths(version))
     links_this_version.append(main_memory.registerRestApiPaths(version))
     links_this_version.append(network.registerRestApiPaths(version))
+    links_this_version.append(planed.registerRestApiPaths(version))
     
     links["v" + str(version)] = links_this_version
     
