@@ -9,6 +9,7 @@ from typing import List
 
 from JuMonC import settings
 from JuMonC import reset_logging
+from JuMonC.models import planed_tasks
 
 
 logger = logging.getLogger(__name__)
@@ -27,6 +28,7 @@ def parseCMDOptions(args: List[str] = None) -> None:
 def setupParser() -> argparse.ArgumentParser:
     #pylint: disable=import-outside-toplevel
     from JuMonC._version import __DB_version__, __REST_version__, REST_version_info, __version__
+    from JuMonC.helpers.PluginManager import addPluginArgs
     #pylint: enable=import-outside-toplevel
 
     parser = argparse.ArgumentParser(description=("JuMonC is the Jülich Monitoring and Control programm, "
@@ -49,6 +51,11 @@ def setupParser() -> argparse.ArgumentParser:
                        help=("Path and filename to either an existing JuMonC database, that wil lbe used, or a new one that will be created"),
                        default="JuMonC.db",
                        type=str)
+    parser.add_argument("--DISABLE_SCHEDULED_TASKS",
+                       dest="SCHEDULED_TASKS_ENABLED",
+                       help="Allows to disable the execution and REST-API paths used for task scheduling",
+                       default=True,
+                       action='store_false')
     parser.add_argument("--DONT_DEFAULT_TO_HUMAN_READABLE_NUMBERS", 
                        dest="DONT_DEFAULT_TO_HUMAN_READABLE_NUMBERS", 
                        help="Sets wether numbers are converted into smaller numbers by default, can be overwritten for each API call", 
@@ -108,6 +115,13 @@ def setupParser() -> argparse.ArgumentParser:
                        default=REST_version_info[0], 
                        choices=range(REST_version_info[0]+1), 
                        type=int)
+    parser.add_argument("--SCHEDULE_TASK", 
+                       dest="SCHEDULE_TASK", 
+                       help="schedule tasks, repetition time[ms] followed by the REST-API path, separated by:. Example \"1000:/v1/cpu/status/load?token=12345678\"", 
+                       default=[],
+                       action='append',
+                       #nargs='*',
+                       type=str)
     parser.add_argument("--SHORT_JOB_MAX_TIME", 
                        dest="SHORT_JOB_MAX_TIME", 
                        help=("Short jobs will be executed rigth away and return results directly via REST-API, "
@@ -144,6 +158,8 @@ def setupParser() -> argparse.ArgumentParser:
                        action='version', 
                        version=f'JuMonC\'s {__version__},\n REST-API\'s {__REST_version__},\n DB\'s {__DB_version__}')
     
+    addPluginArgs()
+    
     return parser
 
 
@@ -151,6 +167,10 @@ def setupParser() -> argparse.ArgumentParser:
 
 
 def evaluateArgs(parser: argparse.ArgumentParser, args: List[str]) -> None:
+    #pylint: disable=import-outside-toplevel
+    from JuMonC.helpers.PluginManager import evaluatePluginArgs
+    #pylint: enable=import-outside-toplevel
+    
     parsed = parser.parse_args(args)
 
     evaluateLogArgs(parsed)
@@ -159,6 +179,9 @@ def evaluateArgs(parser: argparse.ArgumentParser, args: List[str]) -> None:
     evaluateThreadingArgs(parsed)
     evaluateSecurityArgs(parsed)
     evaluateMiscellaneousArgs(parsed)
+    evaluateSchedulingArgs(parsed)
+    
+    evaluatePluginArgs(parsed)
 
 
 
@@ -291,4 +314,17 @@ def evaluateSecurityArgs(parsed:argparse.Namespace) -> None:
 def evaluateMiscellaneousArgs(parsed:argparse.Namespace) -> None:
 
     settings.PLUGIN_PATHS.extend(parsed.PLUGIN_PATHS)
-    logging.info("Set PLUGIN_PATHS to %s", str(settings.PLUGIN_PATHS))
\ No newline at end of file
+    logging.info("Set PLUGIN_PATHS to %s", str(settings.PLUGIN_PATHS))
+
+
+def evaluateSchedulingArgs(parsed:argparse.Namespace) -> None:
+    settings.SCHEDULED_TASKS_ENABLED = parsed.SCHEDULED_TASKS_ENABLED
+    logging.info("Set SCHEDULED_TASKS_ENABLED to %s", str(settings.SCHEDULED_TASKS_ENABLED))
+
+    if settings.SCHEDULED_TASKS_ENABLED:
+        settings.SCHEDULE_TASKS.extend(parsed.SCHEDULE_TASK)
+        logging.info("SCHEDULE_TASK: %s", str(settings.SCHEDULE_TASKS))
+        for task in settings.SCHEDULE_TASKS:
+            split = task.split(":")
+            planed_tasks.addScheduledTask(":".join(split[1:]), int(split[0]))
+    
