@@ -1,6 +1,6 @@
 from JuMonC.tasks import Plugin
 
-class SlurmPlugin(Plugin.Plugin):
+class _SlurmPlugin(Plugin.Plugin):
     
     def _isWorking(self) -> bool:
         return False
\ No newline at end of file
